frccontrol
##########

Provides SciPy wrappers for easing development of state-space models for
the FIRST Robotics Competition.

Dependencies
************

- `Python 3.5 or newer <https://www.python.org/downloads/>`_
- Matplotlib
- NumPy
- SciPy

Installation
************

On Windows, execute::

    py -m pip install frccontrol

On Linux/OSX, execute::

    pip install frccontrol
